==> qmmp_1.1.10.orig.tar.bz2: qmmp-1.1.10/src/plugins/Input/mpc/translations/mpc_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="59"/>
        <source>Musepack Plugin</source>
        <translation>Музпак прикључак</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="61"/>
        <source>Musepack Files</source>
        <translation>Музпак фајлови</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="125"/>
        <source>About Musepack Audio Plugin</source>
        <translation>О Музпак прикључку</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="126"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Кумп Музпак прикључак</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="127"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Дужина</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Узорковање</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Канала</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Битски проток</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/mpc/translations/mpc_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="53"/>
        <source>Musepack Plugin</source>
        <translation>Музпак прикључак</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="55"/>
        <source>Musepack Files</source>
        <translation>Музпак фајлови</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="119"/>
        <source>About Musepack Audio Plugin</source>
        <translation>О Музпак прикључку</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="120"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Кумп Музпак прикључак</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="121"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>Дужина</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>Узорковање</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>Канала</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>Битски проток</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
